@@ -1,6 +1,6 @@
 tangleR<-
-function(in.file,out.file,expand.roots=NULL,expand.root.start=TRUE,insert.comments=TRUE,
-         add.extension=TRUE){
+function(in.file,out.file,expand.roots=NULL,expand.root.start=TRUE,
+         insert.comments=TRUE,add.extension=TRUE){
   # german documentation of the code:
   # look for file webR.pdf, P. Wolf 050204
   if(!file.exists(in.file)) in.file<-paste(in.file,"rev",sep=".")
@@ -8,12 +8,16 @@ function(in.file,out.file,expand.roots=NULL,expand.root.start=TRUE,insert.commen
     cat(paste("ERROR:",in.file,"not found!!??\n"))
     return("Error in tangle: file not found")
   }
-  # code.ch<-scan(in.file,sep="\n",what=" ")
+  # code.ch<-scan(in.file,sep="\n",what=" ",blank.lines.skip =FALSE)
   code.ch<-readLines(in.file) # 2.1.0
 
   code.ch<-c(code.ch,"@")
   code.a<- grep("^<<(.*)>>=",code.ch)
   if(0==length(code.a)){return("Warning: no code found!!!!")}
+    # was tun, wenn mehrere code chunks nicht durch text chunks getrennt wurden? 090220
+    aa<-as.list(code.ch)
+    aa[code.a]<-lapply(aa[code.a],function(x) c("@",x)) 
+    code.ch<-unlist(aa); code.a<- grep("^<<(.*)>>=",code.ch)
   code.z<-grep("^@",code.ch)
   code.z    <-unlist(sapply(code.a ,function(x,y)min(y[y>x]),code.z))
   code.n    <-length(code.ch)
